@@ -104,7 +104,6 @@ def mk_InstrumentBlock(my_data, number=1, moav=0, sa=False):
     #subscript_nums = ['', '₁', '₂', '₃', '₄', '₅', '₆', '₇', '₈', '₉']
     supscript_nums = ['', '¹', '²', '³', '⁴', '⁵', '⁶', '⁷', '⁸', '⁹']
 
-    from model_repo import Instrument_Model as insmod
     pnames = ['Offset', 'Jitter']
     punits = [r'($\frac{m}{s}$)', r'($\frac{m}{s}$)']
     math_display = f'γ₀|{supscript_nums[number]}'
@@ -153,18 +152,18 @@ def mk_InstrumentBlock(my_data, number=1, moav=0, sa=False):
 
 
     if moav > 0:
-        from model_repo import Instrument_Moav_Model as insmod
+        insmod = Instrument_Moav_Model
         b_mod = ModelWrapper(insmod, [number, my_data.values[:, 3], moav,
                              my_data.values[:, 0], my_data.values[:, 1]])
         b_script = 'ins01.model'
         if sa:
-            from model_repo import Instrument_Moav_SA_Model as insmod
+            insmod = Instrument_Moav_SA_Model
             b_mod = ModelWrapper(insmod, [number, my_data.values[:, 3], moav,
                                  my_data.values[:, 0], my_data.values[:, 4:],
                                  my_data.shape[1]-4])
             b_script = None
     else:
-        from model_repo import Instrument_Model as insmod
+        insmod = Instrument_Model
         b_mod = ModelWrapper(insmod, [number, my_data.values[:, 3]])
         b_script = 'ins00.model'
 
@@ -184,7 +183,7 @@ def mk_AccelerationBlock(my_data, n=1):
     subscript_nums = ['', '₁', '₂', '₃', '₄', '₅', '₆', '₇', '₈', '₉']
     #supscript_nums = ['', '¹', '²', '³', '⁴', '⁵', '⁶', '⁷', '⁸', '⁹']
     punits = []
-    from model_repo import Acceleration_Model as acmod
+    acmod = Acceleration_Model
     for i in range(n):
         if i == 0:
             pnames = ['Acceleration']
@@ -244,8 +243,7 @@ def mk_AccelerationBlock(my_data, n=1):
 
 def mk_AdditionalPriorsBlock(my_data):
     my_params = []
-
-    from model_repo import Empty_Model as empmod
+    empmod = Empty_Model
     b_mod = ModelWrapper(empmod, [my_data.values[:, 0]])
     b_name = 'AdditionalPriorsBlock'
 
